/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "talk.h"
#define SCALE 16

texture_t text;
primitive_t primitive;

void pokerTalkInit(poker_t *poker) {
  poker->talkText = NULL;
  poker->talkTextInfo = NULL;
  poker->lastWidth = 0, poker->lastHeight = 0;

  // Testing
  assetTextureLoad(&text, "red.png");
  quadInit(&primitive, 0,  0, 0, 0, 0,  0, 0, 0, 0);
}

void pokerTalkDispose(poker_t *poker) {
  if(poker->talkTextInfo == NULL) return;
  fontTextInfoDispose(poker->talkTextInfo);
  primitiveDispose(&poker->talkPrimitive);
}

void pokerTalkTextRebuffer(poker_t *poker, render_t *render) {
  // Check if we need to force a redraw or not.
  if(poker->talkText == NULL || poker->lastWidth != render->width) {
    if(poker->talkTextInfo != NULL) {
      fontTextInfoDispose(poker->talkTextInfo);
      primitiveDispose(&poker->talkPrimitive);
    }
  }

  poker->lastWidth = render->width;
  poker->lastHeight = render->height;
  if(poker->talkText == NULL) return;

  // Rebuffer
  poker->talkTextInfo = fontTextClamp(&poker->font,poker->talkText,render->width);
  fontTextInit(&poker->font, &poker->talkPrimitive, poker->talkTextInfo);
}

void pokerTalkRender(poker_t *poker, render_t *render) {
  pokerTalkTextRebuffer(poker, render);

  if(poker->talkTextInfo == NULL) return;
  shaderUsePosition(&poker->shader, 0,0,0, 0,0,0);
  shaderUseTexture(&poker->shader, &poker->font.texture);
  primitiveDraw(&poker->talkPrimitive, 0, -1);

  primitiveDispose(&primitive);
  quadInit(&primitive, -0.05,  0, 0, 0.25, 0.25,  poker->talkTextInfo->width, poker->talkTextInfo->height, 0.35, 0.35);
  
  shaderUsePosition(&poker->shader, 0,0,0, 0,0,0);
  shaderUseTexture(&poker->shader, &text);
  primitiveDraw(&primitive, 0, -1);
}

void pokerTalk(poker_t *poker, char *text) {
  poker->talkText = text;
}